@@ -33,6 +33,7 @@
 #include "eel-gtk-extensions.h"
 #include "eel-stock-dialogs.h"
 #include "eel-i18n.h"
+#include "egg-screen-exec.h"
 #include <X11/Xatom.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -70,15 +71,27 @@ struct IconSelectionData {
 typedef struct IconSelectionData IconSelectionData;
 
 void 
-eel_gnome_shell_execute (const char *command)
+eel_gnome_shell_execute_on_screen (const char *command,
+				   GdkScreen  *screen)
 {
 	GError *error = NULL;
-	if (!g_spawn_command_line_async (command, &error)) {
+
+	if (screen == NULL) {
+		screen = gdk_screen_get_default ();
+	}
+
+	if (!egg_screen_execute_command_line_async (screen, command, &error)) {
 		g_warning ("Error starting command '%s': %s\n", command, error->message);
 		g_error_free (error);
 	}
 }
 
+void 
+eel_gnome_shell_execute (const char *command)
+{
+	eel_gnome_shell_execute_on_screen (command, NULL);
+}
+
 /* Return a command string containing the path to a terminal on this system. */
 
 static char *
@@ -207,7 +220,8 @@ eel_gnome_make_terminal_command (const char *command)
 }
 
 void
-eel_gnome_open_terminal (const char *command)
+eel_gnome_open_terminal_on_screen (const char *command,
+				   GdkScreen  *screen)
 {
 	char *command_line;
 	
@@ -216,10 +230,16 @@ eel_gnome_open_terminal (const char *command)
 		g_message ("Could not start a terminal");
 		return;
 	}
-	eel_gnome_shell_execute (command_line);
+	eel_gnome_shell_execute_on_screen (command_line, screen);
 	g_free (command_line);
 }
 
+void
+eel_gnome_open_terminal (const char *command)
+{
+	eel_gnome_open_terminal_on_screen (command, NULL);
+}
+
 /* create a new icon selection dialog */
 static gboolean
 widget_destroy_callback (gpointer callback_data)
@@ -262,8 +282,9 @@ icon_selected (IconSelectionData *selection_data)
 	 */
 	stat (icon_path, &buf);
 	if (S_ISDIR (buf.st_mode)) {
-		eel_show_error_dialog (_("No image was selected.  You must click on an image to select it."),
-				       _("No selection made"),
+		eel_show_error_dialog (_("No image was selected."),
+		                       _("You must click on an image to select it."),
+				       _("No Selection Made"),
 				       selection_data->owning_window);
 	} else {	 
 		/* invoke the callback to inform it of the file path */
@@ -273,7 +294,7 @@ icon_selected (IconSelectionData *selection_data)
 	/* We have to get rid of the icon selection dialog, but we can't do it now, since the
 	 * file entry might still need it. Do it when the next idle rolls around
 	 */ 
-	gtk_idle_add (widget_destroy_callback, selection_data);
+	g_idle_add (widget_destroy_callback, selection_data);
 }
 
 /* handle the cancel button being pressed */
@@ -293,13 +314,14 @@ icon_cancel_pressed (IconSelectionData *selection_data)
 static void
 list_icon_selected_callback (GnomeIconList *gil, int num, GdkEvent *event, IconSelectionData *selection_data)
 {
-	const char *icon;
+	char *icon;
 	GtkWidget *entry;
 	
 	icon = gnome_icon_selection_get_icon (GNOME_ICON_SELECTION (selection_data->icon_selection), TRUE);
 	if (icon != NULL) {
 		entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (selection_data->file_entry));
 		gtk_entry_set_text (GTK_ENTRY (entry), icon);
+		g_free (icon);
 	}
 
 	/* handle double-clicks as if the user pressed OK */
@@ -393,7 +415,6 @@ eel_gnome_icon_selector_new (const char *title,
 	if (owner != NULL) {
 		gtk_window_set_transient_for (GTK_WINDOW (dialog), owner);
  	}
- 	gtk_window_set_wmclass (GTK_WINDOW (dialog), "file_selector", "Eel");
 	gtk_widget_show_all (dialog);
 	
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (file_entry));
@@ -440,85 +461,6 @@ eel_bonobo_make_registration_id (const char *iid)
 		iid, DisplayString (gdk_display));
 }
 
-static ORBit_IMethod *
-get_set_value_imethod (void)
-{
-	static ORBit_IMethod *imethod = NULL;
-
-	if (!imethod) {
-		guint i;
-		ORBit_IMethods *methods;
-
-		methods = &Bonobo_PropertyBag__iinterface.methods;
-
-		for (i = 0; i < methods->_length; i++) {
-			if (!strcmp (methods->_buffer [i].name,
-				     "setValue"))
-				imethod = &methods->_buffer [i];
-		}
-		g_assert (imethod != NULL);
-	}
-
-	return imethod;
-}
-
-static void
-do_nothing_cb (CORBA_Object          object,
-	       ORBit_IMethod        *m_data,
-	       ORBitAsyncQueueEntry *aqe,
-	       gpointer              user_data, 
-	       CORBA_Environment    *ev)
-{
-	/* FIXME: we can remove this when people
-	   have the fixed ORB more prevelantly */
-}
-
-/**
- * eel_bonobo_pbclient_set_value_async:
- * @bag: a reference to the PropertyBag
- * @key: key of the value to set
- * @value: the new value
- * @opt_ev: an optional CORBA_Environment to return failure codes
- *
- * Set a value on the PropertyBag asynchronously, discarding any
- * possible roundtrip exceptions.
- */
-void
-eel_bonobo_pbclient_set_value_async (Bonobo_PropertyBag  bag,
-				     const char         *key,
-				     CORBA_any          *value,
-				     CORBA_Environment  *opt_ev)
-{
-	gpointer args [2];
-	CORBA_Environment ev, *my_ev;
-
-	g_return_if_fail (key != NULL);
-	g_return_if_fail (value != NULL);
-	g_return_if_fail (bag != CORBA_OBJECT_NIL);
-
-	if (!opt_ev) {
-		CORBA_exception_init (&ev);
-		my_ev = &ev;
-	} else
-		my_ev = opt_ev;
-
-	if (BONOBO_EX (my_ev) || bag == CORBA_OBJECT_NIL) {
-		if (!opt_ev)
-			CORBA_exception_free (&ev);
-		return;
-	}
-
-	args [0] = (gpointer) &key;
-	args [1] = (gpointer) value;
-
-	ORBit_small_invoke_async
-		(bag, get_set_value_imethod (),
-		 do_nothing_cb, NULL, args, NULL, my_ev);
-	
-	if (!opt_ev)
-		CORBA_exception_free (&ev);
-}
-
 /**
  * eel_glade_get_file:
  * @filename: the XML file name.
