@@ -69,7 +69,7 @@ enum
 	PROP_X_ALIGNMENT,
 	PROP_X_PADDING,
 	PROP_Y_ALIGNMENT,
-	PROP_Y_PADDING
+	PROP_Y_PADDING,
 };
 
 /* Detail member struct */
@@ -141,7 +141,7 @@ static EelDimensions labeled_image_get_image_dimensions   (const EelLabeledImage
 static EelDimensions labeled_image_get_label_dimensions   (const EelLabeledImage *labeled_image);
 static void          labeled_image_ensure_label           (EelLabeledImage       *labeled_image);
 static void          labeled_image_ensure_image           (EelLabeledImage       *labeled_image);
-static EelIRect      labeled_image_get_content_bounds     (const EelLabeledImage *labeled_image);
+static ArtIRect      labeled_image_get_content_bounds     (const EelLabeledImage *labeled_image);
 static EelDimensions labeled_image_get_content_dimensions (const EelLabeledImage *labeled_image);
 static void          labeled_image_update_alignments      (EelLabeledImage       *labeled_image);
 static gboolean      labeled_image_show_label             (const EelLabeledImage *labeled_image);
@@ -295,7 +295,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 				      G_PARAM_READWRITE));
 }
 
-static void
+void
 eel_labeled_image_init (EelLabeledImage *labeled_image)
 {
 	GTK_WIDGET_SET_FLAGS (labeled_image, GTK_NO_WINDOW);
@@ -354,7 +354,7 @@ eel_labeled_image_set_property (GObject      *object,
 {
 	EelLabeledImage *labeled_image;
 	
-	g_assert (EEL_IS_LABELED_IMAGE (object));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (object));
 
  	labeled_image = EEL_LABELED_IMAGE (object);
 
@@ -426,7 +426,7 @@ eel_labeled_image_get_property (GObject    *object,
 {
 	EelLabeledImage *labeled_image;
 
-	g_assert (EEL_IS_LABELED_IMAGE (object));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (object));
 	
 	labeled_image = EEL_LABELED_IMAGE (object);
 
@@ -491,8 +491,8 @@ eel_labeled_image_size_request (GtkWidget *widget,
 	EelLabeledImage *labeled_image;
  	EelDimensions content_dimensions;
 
- 	g_assert (EEL_IS_LABELED_IMAGE (widget));
- 	g_assert (requisition != NULL);
+ 	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
+ 	g_return_if_fail (requisition != NULL);
 
   	labeled_image = EEL_LABELED_IMAGE (widget);
 	
@@ -512,11 +512,11 @@ eel_labeled_image_size_allocate (GtkWidget *widget,
 				 GtkAllocation *allocation)
 {
 	EelLabeledImage *labeled_image;
- 	EelIRect image_bounds;
-	EelIRect label_bounds;
+ 	ArtIRect image_bounds;
+	ArtIRect label_bounds;
 
- 	g_assert (EEL_IS_LABELED_IMAGE (widget));
- 	g_assert (allocation != NULL);
+ 	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
+ 	g_return_if_fail (allocation != NULL);
 
   	labeled_image = EEL_LABELED_IMAGE (widget);
 
@@ -538,11 +538,11 @@ eel_labeled_image_expose_event (GtkWidget *widget,
 				GdkEventExpose *event)
 {
 	EelLabeledImage *labeled_image;
-	EelIRect label_bounds;
+	ArtIRect label_bounds;
 
-	g_assert (EEL_IS_LABELED_IMAGE (widget));
-	g_assert (GTK_WIDGET_REALIZED (widget));
-	g_assert (event != NULL);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (widget), TRUE);
+	g_return_val_if_fail (GTK_WIDGET_REALIZED (widget), TRUE);
+	g_return_val_if_fail (event != NULL, TRUE);
 
   	labeled_image = EEL_LABELED_IMAGE (widget);
 
@@ -593,7 +593,7 @@ eel_labeled_image_map (GtkWidget *widget)
 {
 	EelLabeledImage *labeled_image;
 
-	g_assert (EEL_IS_LABELED_IMAGE (widget));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
 	
 	labeled_image = EEL_LABELED_IMAGE (widget);
 
@@ -613,7 +613,7 @@ eel_labeled_image_unmap (GtkWidget *widget)
 {
 	EelLabeledImage *labeled_image;
 
-	g_assert (EEL_IS_LABELED_IMAGE (widget));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
 	
 	labeled_image = EEL_LABELED_IMAGE (widget);
 
@@ -628,7 +628,7 @@ static void
 eel_labeled_image_add (GtkContainer *container,
 		       GtkWidget *child)
 {
-	g_assert (GTK_IS_LABEL (child) || GTK_IS_IMAGE (child));
+	g_return_if_fail (GTK_IS_LABEL (child) || GTK_IS_IMAGE (child));
 
 	eel_gtk_container_child_add (container, child);
 }
@@ -639,11 +639,11 @@ eel_labeled_image_remove (GtkContainer *container,
 {
 	EelLabeledImage *labeled_image;
 	
-	g_assert (GTK_IS_LABEL (child) || GTK_IS_IMAGE (child));
+	g_return_if_fail (GTK_IS_LABEL (child) || GTK_IS_IMAGE (child));
 	
 	labeled_image = EEL_LABELED_IMAGE (container);;
 
-	g_assert (child == labeled_image->details->image || child == labeled_image->details->label);
+	g_return_if_fail (child == labeled_image->details->image || child == labeled_image->details->label);
 
 	eel_gtk_container_child_remove (container, child);
 
@@ -664,8 +664,8 @@ eel_labeled_image_forall (GtkContainer *container,
 {
 	EelLabeledImage *labeled_image;
 	
-	g_assert (EEL_IS_LABELED_IMAGE (container));
-	g_assert (callback != NULL);
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (container));
+	g_return_if_fail (callback != NULL);
 	
 	labeled_image = EEL_LABELED_IMAGE (container);
 
@@ -693,7 +693,7 @@ labeled_image_get_image_dimensions (const EelLabeledImage *labeled_image)
 	EelDimensions image_dimensions;
 	GtkRequisition image_requisition;	
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_dimensions_empty);
 
 	if (!labeled_image_show_image (labeled_image)) {
 		return eel_dimensions_empty;
@@ -717,7 +717,7 @@ labeled_image_get_label_dimensions (const EelLabeledImage *labeled_image)
 	EelDimensions label_dimensions;
 	GtkRequisition label_requisition;	
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_dimensions_empty);
 
 	if (!labeled_image_show_label (labeled_image)) {
 		return eel_dimensions_empty;
@@ -731,20 +731,20 @@ labeled_image_get_label_dimensions (const EelLabeledImage *labeled_image)
 	return label_dimensions;
 }
 
-static EelIRect
+static ArtIRect
 labeled_image_get_image_bounds_fill (const EelLabeledImage *labeled_image)
 {
-	EelIRect image_bounds;
+	ArtIRect image_bounds;
 	EelDimensions image_dimensions;
-	EelIRect content_bounds;
-	EelIRect bounds;
+	ArtIRect content_bounds;
+	ArtIRect bounds;
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
 
 	image_dimensions = labeled_image_get_image_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (image_dimensions)) {
-		return eel_irect_empty;
+		return eel_art_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -781,29 +781,22 @@ labeled_image_get_image_bounds_fill (const EelLabeledImage *labeled_image)
 			image_bounds.x1 = bounds.x1;
 			image_bounds.y1 = content_bounds.y0 + image_dimensions.height;
 			break;
-
-		default:
-			image_bounds.x0 = 0;
-			image_bounds.y0 = 0;
-			image_bounds.x1 = 0;
-			image_bounds.y1 = 0;
-			g_assert_not_reached ();
 		}
 	}
 
 	return image_bounds;
 }
 
-EelIRect
+ArtIRect
 eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 {
 	EelDimensions image_dimensions;
 	EelDimensions label_dimensions;
 	GtkRequisition image_requisition;
-	EelIRect image_bounds;
-	EelIRect content_bounds;
+	ArtIRect image_bounds;
+	ArtIRect content_bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
 
 	if (labeled_image->details->fill) {
 		return labeled_image_get_image_bounds_fill (labeled_image);
@@ -821,7 +814,7 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (image_dimensions)) {
-		return eel_irect_empty;
+		return eel_art_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -829,40 +822,40 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	if (!labeled_image_show_label (labeled_image)) {
 		image_bounds.x0 = 
 			content_bounds.x0 +
-			(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+			(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 		image_bounds.y0 = 
 			content_bounds.y0 +
-			(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+			(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 	} else {
 		switch (labeled_image->details->label_position) {
 		case GTK_POS_LEFT:
 			image_bounds.x0 = content_bounds.x1 - image_dimensions.width;
 			image_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+				(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_RIGHT:
 			image_bounds.x0 = content_bounds.x0;
 			image_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+				(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_TOP:
 			image_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+				(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 			image_bounds.y0 = content_bounds.y1 - image_dimensions.height;
 			break;
 
 		case GTK_POS_BOTTOM:
 			image_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+				(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 				
 			if (is_fixed_height (labeled_image)) {	
-				image_bounds.y0 = content_bounds.y0 + eel_irect_get_height (content_bounds)
+				image_bounds.y0 = content_bounds.y0 + eel_art_irect_get_height (content_bounds)
 					- image_dimensions.height
 					- label_dimensions.height
 					- labeled_image->details->spacing;
@@ -871,11 +864,6 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 			}	
 
 			break;
-
-		default:
-			image_bounds.x0 = 0;
-			image_bounds.y0 = 0;
-			g_assert_not_reached ();
 		}
 	}
 	
@@ -885,20 +873,20 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	return image_bounds;
 }
 
-static EelIRect
+static ArtIRect
 labeled_image_get_label_bounds_fill (const EelLabeledImage *labeled_image)
 {
-	EelIRect label_bounds;
+	ArtIRect label_bounds;
 	EelDimensions label_dimensions;
-	EelIRect content_bounds;
-	EelIRect bounds;
+	ArtIRect content_bounds;
+	ArtIRect bounds;
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
 
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (label_dimensions)) {
-		return eel_irect_empty;
+		return eel_art_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -937,27 +925,20 @@ labeled_image_get_label_bounds_fill (const EelLabeledImage *labeled_image)
 			label_bounds.x1 = bounds.x1;
 			label_bounds.y1 = bounds.y1;
 			break;
-
-		default:
-			label_bounds.x0 = 0;
-			label_bounds.y0 = 0;
-			label_bounds.x1 = 0;
-			label_bounds.y1 = 0;
-			g_assert_not_reached ();
 		}
 	}
 
 	return label_bounds;
 }
 
-EelIRect
+ArtIRect
 eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 {
-	EelIRect label_bounds;
+	ArtIRect label_bounds;
 	EelDimensions label_dimensions;
-	EelIRect content_bounds;
+	ArtIRect content_bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
 
 	if (labeled_image->details->fill) {
 		return labeled_image_get_label_bounds_fill (labeled_image);
@@ -966,7 +947,7 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (label_dimensions)) {
-		return eel_irect_empty;
+		return eel_art_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -975,10 +956,10 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 	if (!labeled_image_show_image (labeled_image)) {
 		label_bounds.x0 = 
 			content_bounds.x0 +
-			(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+			(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 		label_bounds.y0 = 
 			content_bounds.y0 +
-			(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+			(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 		/* Both label and image are shown */
 	} else {
 		switch (labeled_image->details->label_position) {
@@ -986,34 +967,29 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 			label_bounds.x0 = content_bounds.x0;
 			label_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+				(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_RIGHT:
 			label_bounds.x0 = content_bounds.x1 - label_dimensions.width;
 			label_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+				(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_TOP:
 			label_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+				(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 			label_bounds.y0 = content_bounds.y0;
 			break;
 
 		case GTK_POS_BOTTOM:
 			label_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+				(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 			label_bounds.y0 = content_bounds.y1 - label_dimensions.height;
 			break;
-
-		default:
-			label_bounds.x0 = 0;
-			label_bounds.y0 = 0;
-			g_assert_not_reached ();
 		}
 	}
 	
@@ -1027,7 +1003,7 @@ static void
 labeled_image_update_alignments (EelLabeledImage *labeled_image)
 {
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
 
 	if (labeled_image->details->label != NULL) {
 		float x_alignment;
@@ -1124,7 +1100,7 @@ labeled_image_get_content_dimensions (const EelLabeledImage *labeled_image)
 	EelDimensions label_dimensions;
 	EelDimensions content_dimensions;
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_dimensions_empty);
 
 	image_dimensions = labeled_image_get_image_dimensions (labeled_image);
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
@@ -1163,19 +1139,19 @@ labeled_image_get_content_dimensions (const EelLabeledImage *labeled_image)
 	return content_dimensions;
 }
 
-static EelIRect
+static ArtIRect
 labeled_image_get_content_bounds (const EelLabeledImage *labeled_image)
 {
 	EelDimensions content_dimensions;
-	EelIRect content_bounds;
-	EelIRect bounds;
+	ArtIRect content_bounds;
+	ArtIRect bounds;
 
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
 
 	bounds = eel_gtk_widget_get_bounds (GTK_WIDGET (labeled_image));
 
 	content_dimensions = labeled_image_get_content_dimensions (labeled_image);
-	content_bounds = eel_irect_align (bounds,
+	content_bounds = eel_art_irect_align (bounds,
 					      content_dimensions.width,
 					      content_dimensions.height,
 					      labeled_image->details->x_alignment,
@@ -1187,7 +1163,7 @@ labeled_image_get_content_bounds (const EelLabeledImage *labeled_image)
 static void
 labeled_image_ensure_label (EelLabeledImage *labeled_image)
 {
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
 	
 	if (labeled_image->details->label != NULL) {
 		return;
@@ -1201,7 +1177,7 @@ labeled_image_ensure_label (EelLabeledImage *labeled_image)
 static void
 labeled_image_ensure_image (EelLabeledImage *labeled_image)
 {
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
 	
 	if (labeled_image->details->image != NULL) {
 		return;
@@ -1215,7 +1191,7 @@ labeled_image_ensure_image (EelLabeledImage *labeled_image)
 static gboolean
 labeled_image_show_image (const EelLabeledImage *labeled_image)
 {
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), FALSE);
 	
 	return labeled_image->details->image != NULL && labeled_image->details->show_image;
 }
@@ -1223,7 +1199,7 @@ labeled_image_show_image (const EelLabeledImage *labeled_image)
 static gboolean
 labeled_image_show_label (const EelLabeledImage *labeled_image)
 {
-	g_assert (EEL_IS_LABELED_IMAGE (labeled_image));
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), FALSE);
 
 	return labeled_image->details->label != NULL && labeled_image->details->show_label;
 }
@@ -1754,7 +1730,7 @@ eel_labled_set_mnemonic_widget (GtkWidget *image_widget,
 {
 	EelLabeledImage *image;
 
-	g_assert (EEL_IS_LABELED_IMAGE (image_widget));
+	g_return_if_fail (EEL_IS_LABELED_IMAGE (image_widget));
 
 	image = EEL_LABELED_IMAGE (image_widget);
 
@@ -1927,11 +1903,11 @@ static void
 button_leave_callback (GtkWidget *widget,
 		       gpointer callback_data)
 {
-	g_assert (GTK_IS_WIDGET (widget));
+	g_return_if_fail (GTK_IS_WIDGET (widget));
 
 	if (GTK_WIDGET_DRAWABLE (widget)) {
 		const int fudge = 4;
-		EelIRect bounds;
+		ArtIRect bounds;
 
 		bounds = eel_gtk_widget_get_bounds (widget);
 		
@@ -1943,8 +1919,8 @@ button_leave_callback (GtkWidget *widget,
 		gtk_widget_queue_draw_area (widget->parent,
 					    bounds.x0,
 					    bounds.y0,
-					    eel_irect_get_width (bounds),
-					    eel_irect_get_height (bounds));
+					    eel_art_irect_get_width (bounds),
+					    eel_art_irect_get_height (bounds));
 	}
 }
 
@@ -1953,7 +1929,7 @@ button_focus_out_event_callback (GtkWidget *widget,
 				 GdkEventFocus *event,
 				 gpointer callback_data)
 {
-	g_assert (GTK_IS_WIDGET (widget));
+	g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
 	button_leave_callback (widget, callback_data);
 
@@ -2156,8 +2132,7 @@ eel_labeled_image_accessible_get_name (AtkObject *accessible)
 
 	labeled_image = get_image (accessible);
 
-	if (labeled_image && labeled_image->details &&
-	    labeled_image->details->label)
+	if (labeled_image->details->label)
 		return gtk_label_get_text
 			(GTK_LABEL (labeled_image->details->label));
 
@@ -2247,7 +2222,7 @@ eel_labeled_image_get_accessible (GtkWidget *widget)
 	}
 
 	if (!types [i]) {
-		const GInterfaceInfo atk_image_info = {
+		static const GInterfaceInfo atk_image_info = {
 			(GInterfaceInitFunc) eel_labeled_image_accessible_image_interface_init,
 			(GInterfaceFinalizeFunc) NULL,
 			NULL
