@@ -25,9 +25,11 @@
 #include "eel-preferences-glade.h"
 
 #include <glib.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtktogglebutton.h>
 
 #include "eel-preferences.h"
+#include "eel-string-list.h"
 
 #define EEL_PREFERENCES_GLADE_DATA_KEY "eel_preferences_glade_data_key"
 #define EEL_PREFERENCES_GLADE_DATA_VALUE "eel_preferences_glade_data_value"
@@ -37,27 +39,27 @@
 /* helper */
 
 static void
-eel_preferences_glade_combo_box_update (GtkComboBox *combo_box,
+eel_preferences_glade_option_menu_update (GtkOptionMenu *option_menu,
 					  gpointer value,
 					  GCallback change_callback)
 {
 	GHashTable *map;
-	int active;
+	int history;
 	gpointer key;
 
-	map = (GHashTable *) g_object_get_data (G_OBJECT (combo_box),
+	map = (GHashTable *) g_object_get_data (G_OBJECT (option_menu),
 						EEL_PREFERENCES_GLADE_DATA_MAP);
-	active = GPOINTER_TO_INT (g_hash_table_lookup (map, value));
+	history = GPOINTER_TO_INT (g_hash_table_lookup (map, value));
 
-	if (active == -1) {
+	if (history == -1) {
 		return;
 	}
 
-	key = g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_KEY);
+	key = g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_KEY);
 
-	g_signal_handlers_block_by_func (combo_box, change_callback, key);
-	gtk_combo_box_set_active (combo_box, active);
-	g_signal_handlers_unblock_by_func (combo_box, change_callback, key);
+	g_signal_handlers_block_by_func (option_menu, change_callback, key);
+	gtk_option_menu_set_history (option_menu, history);
+	g_signal_handlers_unblock_by_func (option_menu, change_callback, key);
 }
 
 static void
@@ -150,21 +152,22 @@ eel_preferences_glade_connect_bool_slave (GladeXML *dialog,
 			       G_CALLBACK (eel_preferences_glade_bool_toggled),
 			       g_strdup (key), (GClosureNotify) g_free, 0);
 }
-/* string enum (ComboBox) preference */
+
+/* string enum (OptionMenu) preference */
 
 static void
-eel_preferences_glade_string_enum_combo_box_changed (GtkComboBox *combo_box,
+eel_preferences_glade_string_enum_option_menu_changed (GtkOptionMenu *option_menu,
 						       char *key)
 {
-	int active;
+	int history;
 	char **values;
 	int i;
 
-	active = gtk_combo_box_get_active  (combo_box);
-	values = g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_VALUE);
+	history = gtk_option_menu_get_history (option_menu);
+	values = g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_VALUE);
 
 	i = 0;
-	while (i < active && values[i] != NULL) {
+	while (i < history && values[i] != NULL) {
 		i++;
 	}
 
@@ -176,26 +179,26 @@ eel_preferences_glade_string_enum_combo_box_changed (GtkComboBox *combo_box,
 }
 
 static void
-eel_preferences_glade_string_enum_combo_box_update (GtkComboBox *combo_box)
+eel_preferences_glade_string_enum_option_menu_update (GtkOptionMenu *option_menu)
 {
 	char *value;
 
-	value = eel_preferences_get (g_object_get_data (G_OBJECT (combo_box),
+	value = eel_preferences_get (g_object_get_data (G_OBJECT (option_menu),
 							EEL_PREFERENCES_GLADE_DATA_KEY));
 
-	eel_preferences_glade_combo_box_update (combo_box, value,
-						  G_CALLBACK (eel_preferences_glade_string_enum_combo_box_changed));
+	eel_preferences_glade_option_menu_update (option_menu, value,
+						  G_CALLBACK (eel_preferences_glade_string_enum_option_menu_changed));
 
 	g_free (value);
 }
 
 void
-eel_preferences_glade_connect_string_enum_combo_box (GladeXML *dialog,
+eel_preferences_glade_connect_string_enum_option_menu (GladeXML *dialog,
 						       const char *component,
 						       const char *key,
 						       const char **values)
 {
-	GtkWidget *combo_box;
+	GtkWidget *option_menu;
 	GHashTable *map;
 	int i;
 
@@ -204,7 +207,7 @@ eel_preferences_glade_connect_string_enum_combo_box (GladeXML *dialog,
 	g_return_if_fail (key != NULL);
 	g_return_if_fail (values != NULL);
 	
-	combo_box = glade_xml_get_widget (dialog, component);
+	option_menu = glade_xml_get_widget (dialog, component);
 
 	map = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify) g_free, NULL);
 
@@ -212,68 +215,67 @@ eel_preferences_glade_connect_string_enum_combo_box (GladeXML *dialog,
 		g_hash_table_insert (map, g_strdup (values[i]), GINT_TO_POINTER (i));
 	}
 
-	g_object_set_data_full (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_MAP, map,
+	g_object_set_data_full (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_MAP, map,
 				(GDestroyNotify) g_hash_table_destroy);
-	g_object_set_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_VALUE, values);
-	g_object_set_data_full (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_KEY,
+	g_object_set_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_VALUE, values);
+	g_object_set_data_full (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_KEY,
 				g_strdup (key), (GDestroyNotify) g_free);
 
 	eel_preferences_add_callback_while_alive (key,
-				 		  (EelPreferencesCallback) eel_preferences_glade_string_enum_combo_box_update,
-						  combo_box, G_OBJECT (combo_box));
+				 		  (EelPreferencesCallback) eel_preferences_glade_string_enum_option_menu_update,
+						  option_menu, G_OBJECT (option_menu));
 
 	if (!eel_preferences_key_is_writable (key)) {
-		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (combo_box));
+		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (option_menu));
 	}
 
-	g_signal_connect (G_OBJECT (combo_box), "changed",
-			  G_CALLBACK (eel_preferences_glade_string_enum_combo_box_changed),
-			  g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_KEY));
+	g_signal_connect (G_OBJECT (option_menu), "changed",
+			  G_CALLBACK (eel_preferences_glade_string_enum_option_menu_changed),
+			  g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_KEY));
 
-	eel_preferences_glade_string_enum_combo_box_update (GTK_COMBO_BOX (combo_box));
+	eel_preferences_glade_string_enum_option_menu_update (GTK_OPTION_MENU (option_menu));
 }
 
 void
-eel_preferences_glade_connect_string_enum_combo_box_slave (GladeXML *dialog,
+eel_preferences_glade_connect_string_enum_option_menu_slave (GladeXML *dialog,
 							     const char *component,
 							     const char *key)
 {
-	GtkWidget *combo_box;
+	GtkWidget *option_menu;
 
 	g_return_if_fail (dialog != NULL);
 	g_return_if_fail (component != NULL);
 	g_return_if_fail (key != NULL);
 	
-	combo_box = glade_xml_get_widget (dialog, component);
+	option_menu = glade_xml_get_widget (dialog, component);
 
-	g_assert (g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_MAP) != NULL);
+	g_assert (g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_MAP) != NULL);
 
 	if (!eel_preferences_key_is_writable (key)) {
-		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (combo_box));
+		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (option_menu));
 	}
 
-	g_signal_connect_data (G_OBJECT (combo_box), "changed",
-			       G_CALLBACK (eel_preferences_glade_string_enum_combo_box_changed),
+	g_signal_connect_data (G_OBJECT (option_menu), "changed",
+			       G_CALLBACK (eel_preferences_glade_string_enum_option_menu_changed),
 			       g_strdup (key), (GClosureNotify) g_free, 0);
 }
 
-
 /* int enum preference */
 
 static void
-eel_preferences_glade_int_enum_changed (GtkComboBox *combo_box,
+eel_preferences_glade_int_enum_changed (GtkOptionMenu *option_menu,
 					char *key)
 {
-	int active;
+	int history;
 	GSList *value_list;
 	int i;
 
-	active = gtk_combo_box_get_active (combo_box);
-	value_list = (GSList *) g_object_get_data (G_OBJECT (combo_box),
+	history = gtk_option_menu_get_history (option_menu);
+	value_list = (GSList *) g_object_get_data (G_OBJECT (option_menu),
 						   EEL_PREFERENCES_GLADE_DATA_VALUE);
 
 	i = 0;
-	while (i < active && value_list->next != NULL) {
+	while (i < history && value_list->next != NULL) {
 		i++;
 		value_list = value_list->next;
 	}
@@ -286,14 +288,14 @@ eel_preferences_glade_int_enum_changed (GtkComboBox *combo_box,
 }
 
 static void
-eel_preferences_glade_int_enum_update (GtkComboBox *combo_box)
+eel_preferences_glade_int_enum_update (GtkOptionMenu *option_menu)
 {
 	int value;
 
-	value = eel_preferences_get_integer (g_object_get_data (G_OBJECT (combo_box),
+	value = eel_preferences_get_integer (g_object_get_data (G_OBJECT (option_menu),
 								EEL_PREFERENCES_GLADE_DATA_KEY));
 
-	eel_preferences_glade_combo_box_update (combo_box, GINT_TO_POINTER (value),
+	eel_preferences_glade_option_menu_update (option_menu, GINT_TO_POINTER (value),
 						  G_CALLBACK (eel_preferences_glade_int_enum_changed));
 }
 
@@ -306,7 +308,7 @@ eel_preferences_glade_connect_int_enum (GladeXML *dialog,
 	GHashTable *map;
 	int i;
 	int value;
-	GtkComboBox *combo_box;
+	GtkOptionMenu *option_menu;
 	GSList *value_list;
 
 	g_return_if_fail (dialog != NULL);
@@ -314,7 +316,7 @@ eel_preferences_glade_connect_int_enum (GladeXML *dialog,
 	g_return_if_fail (key != NULL);
 	g_return_if_fail (values != NULL);
 	
-	combo_box = GTK_COMBO_BOX (glade_xml_get_widget (dialog, component));
+	option_menu = GTK_OPTION_MENU (glade_xml_get_widget (dialog, component));
 
 	map = g_hash_table_new (g_direct_hash, g_direct_equal);
 	value_list = NULL;
@@ -325,26 +327,26 @@ eel_preferences_glade_connect_int_enum (GladeXML *dialog,
 		g_hash_table_insert (map, GINT_TO_POINTER (value), GINT_TO_POINTER (i));
 	}
 
-	g_object_set_data_full (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_MAP, map,
+	g_object_set_data_full (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_MAP, map,
 				(GDestroyNotify) g_hash_table_destroy);
-	g_object_set_data_full (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_VALUE, value_list,
+	g_object_set_data_full (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_VALUE, value_list,
 				(GDestroyNotify) g_slist_free);
-	g_object_set_data_full (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_KEY,
+	g_object_set_data_full (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_KEY,
 				g_strdup (key), (GDestroyNotify) g_free);
 
 	if (!eel_preferences_key_is_writable (key)) {
-		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (combo_box));
+		eel_preferences_glade_set_never_sensitive (GTK_WIDGET (option_menu));
 	}
 
-	g_signal_connect (G_OBJECT (combo_box), "changed",
+	g_signal_connect (G_OBJECT (option_menu), "changed",
 			  G_CALLBACK (eel_preferences_glade_int_enum_changed),
-			  g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_KEY));
+			  g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_KEY));
 
 	eel_preferences_add_callback_while_alive (key,
 				 		  (EelPreferencesCallback) eel_preferences_glade_int_enum_update,
-						  combo_box, G_OBJECT (combo_box));
+						  option_menu, G_OBJECT (option_menu));
 
-	eel_preferences_glade_int_enum_update (combo_box);
+	eel_preferences_glade_int_enum_update (option_menu);
 }
 
 /* String Enum (RadioButton) preference */
@@ -447,55 +449,59 @@ eel_preferences_glade_connect_string_enum_radio_button (GladeXML *dialog,
 /* list enum preference */
 
 static void
-eel_preferences_glade_list_enum_changed (GtkComboBox *combo_box,
+eel_preferences_glade_list_enum_changed (GtkOptionMenu *option_menu,
 					 char *key)
 {
 	GSList *widgets;
-	int active;
+	int history;
 	char **values;
 	int i;
-	GPtrArray *v;
+	EelStringList *list;
 
-	widgets = g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_WIDGETS);
+	widgets = g_object_get_data (G_OBJECT (option_menu), EEL_PREFERENCES_GLADE_DATA_WIDGETS);
 
-	v = g_ptr_array_new ();
+	list = eel_string_list_new (TRUE);
 	for (; widgets != NULL; widgets = widgets->next) {
-		active = gtk_combo_box_get_active (GTK_COMBO_BOX (widgets->data));
-		values = g_object_get_data (G_OBJECT (combo_box),
+		history = gtk_option_menu_get_history (GTK_OPTION_MENU (widgets->data));
+		values = g_object_get_data (G_OBJECT (option_menu),
 					    EEL_PREFERENCES_GLADE_DATA_VALUE);
 
 		i = 0;
-		while (i < active && values[i] != NULL) {
+		while (i < history && values[i] != NULL) {
 			i++;
 		}
 
 		if (values[i] != NULL) {
-			g_ptr_array_add (v, values[i]);
+			eel_string_list_insert (list, g_strdup (values[i]));
 		}
 	}
-	g_ptr_array_add (v, NULL);
 
-	eel_preferences_set_string_array (key, (char **) v->pdata);
-	g_ptr_array_free (v, TRUE);
+	eel_preferences_set_string_list (key, list);
+	eel_string_list_free (list);
 }
 
 static void
 eel_preferences_glade_list_enum_update (GtkWidget *widget)
 {
-	char **values;
+	EelStringList *value_list;
+	int values;
 	GSList *components;
 	int i;
+	char *item;
 
-	values = eel_preferences_get_string_array (g_object_get_data (G_OBJECT (widget),
-								      EEL_PREFERENCES_GLADE_DATA_KEY));
+	value_list = eel_preferences_get_string_list (g_object_get_data (G_OBJECT (widget),
+									 EEL_PREFERENCES_GLADE_DATA_KEY));
+	values = eel_string_list_get_length (value_list);
 	components = g_object_get_data (G_OBJECT (widget), EEL_PREFERENCES_GLADE_DATA_WIDGETS);
-	for (i = 0; values[i] != NULL && components != NULL; i++, components = components->next) {
-		eel_preferences_glade_combo_box_update (GTK_COMBO_BOX (components->data), 
-							values[i],
-							G_CALLBACK (eel_preferences_glade_list_enum_changed));
+	for (i = 0; i < values && components != NULL; i++, components = components->next) {
+		item = eel_string_list_nth (value_list, i);
+		eel_preferences_glade_option_menu_update (GTK_OPTION_MENU (components->data), 
+							  item,
+							  G_CALLBACK (eel_preferences_glade_list_enum_changed));
+		g_free (item);
 	}
 
-	g_strfreev (values);
+	eel_string_list_free (value_list);
 }
 
 void 
@@ -504,7 +510,7 @@ eel_preferences_glade_connect_list_enum (GladeXML *dialog,
 					 const char *key,
 					 const char **values)
 {
-	GtkWidget *combo_box;
+	GtkWidget *option_menu;
 	GHashTable *map;
 	int i;
 	GSList *widgets;
@@ -523,43 +529,43 @@ eel_preferences_glade_connect_list_enum (GladeXML *dialog,
 
 	writable = eel_preferences_key_is_writable (key);
 
-	combo_box = NULL;
+	option_menu = NULL;
 	widgets = NULL;
 	for (i = 0; components[i] != NULL; i++) {
-		combo_box = glade_xml_get_widget (dialog, components[i]);
-		widgets = g_slist_append (widgets, combo_box);
+		option_menu = glade_xml_get_widget (dialog, components[i]);
+		widgets = g_slist_append (widgets, option_menu);
 		if (i == 0) {
-			g_object_set_data_full (G_OBJECT (combo_box),
+			g_object_set_data_full (G_OBJECT (option_menu),
 						EEL_PREFERENCES_GLADE_DATA_MAP, map,
 						(GDestroyNotify) g_hash_table_destroy);
-			g_object_set_data_full (G_OBJECT (combo_box),
+			g_object_set_data_full (G_OBJECT (option_menu),
 						EEL_PREFERENCES_GLADE_DATA_WIDGETS,
 						widgets, (GDestroyNotify) g_slist_free);
 		} else {
-			g_object_set_data (G_OBJECT (combo_box),
+			g_object_set_data (G_OBJECT (option_menu),
 					   EEL_PREFERENCES_GLADE_DATA_MAP, map);
-			g_object_set_data (G_OBJECT (combo_box),
+			g_object_set_data (G_OBJECT (option_menu),
 					   EEL_PREFERENCES_GLADE_DATA_WIDGETS, widgets);
 		}
-		g_object_set_data (G_OBJECT (combo_box),
+		g_object_set_data (G_OBJECT (option_menu),
 				   EEL_PREFERENCES_GLADE_DATA_VALUE, values);
-		g_object_set_data_full (G_OBJECT (combo_box),
+		g_object_set_data_full (G_OBJECT (option_menu),
 				        EEL_PREFERENCES_GLADE_DATA_KEY, g_strdup (key),
 					(GDestroyNotify) g_free);
 
 		if (!writable) {
-			eel_preferences_glade_set_never_sensitive (combo_box);
+			eel_preferences_glade_set_never_sensitive (option_menu);
 		}
 
-		g_signal_connect (G_OBJECT (combo_box), "changed",
+		g_signal_connect (G_OBJECT (option_menu), "changed",
 			  	  G_CALLBACK (eel_preferences_glade_list_enum_changed),
-				  g_object_get_data (G_OBJECT (combo_box),
+				  g_object_get_data (G_OBJECT (option_menu),
 					  	     EEL_PREFERENCES_GLADE_DATA_KEY));
 	}
 
 	eel_preferences_add_callback_while_alive (key,
 						  (EelPreferencesCallback) eel_preferences_glade_list_enum_update,
-						  combo_box, G_OBJECT (combo_box));
+						  option_menu, G_OBJECT (option_menu));
 	
-	eel_preferences_glade_list_enum_update (combo_box);
+	eel_preferences_glade_list_enum_update (option_menu);
 }
